==> dmhubsdk-1.0.6.tar.gz: lib/src/models/dmhub_options.dart <==
import 'dmhub_domain.dart';

class DMHubOptions {
  /// convertlab appId,trackUrl,appName 必须设置。
  String? trackUrl;
  String? appId;
  String? appName;
  //flushInterval 上传数据的时间间隔（单位：秒），默认值：30
  int? flushInterval = 30; //only for ios
  bool? enableDebugLogging = true; //only for android
  bool? autoTrackOpenAppEvent = true; //only for all

  // 判断应用活跃时间上报需满足c  minimumActiveDuration <= 实际活跃时间 <= activeTimeoutDuration
  int minimumActiveDuration = 10 * 1000; // 进入后台时判定，距离上次最小活跃时间判定阈值
  int activeTimeoutDuration = 2147483647; // 进入后台是判定，最大活跃超时时间阈值，如果超出该阈值则断言为一个新的应用生命周期
  int maximumBackgroundDuration = 30 * 1000; // 从后台恢复时判定，最大后台活跃时间阈值，如果超出该阈值则判断位一个新的生命周期

  DMHubOptions(
      {required this.trackUrl,
      required this.appId,
      required this.appName,
      this.enableDebugLogging,
      this.autoTrackOpenAppEvent});

  factory DMHubOptions.fromJson(Map<String, dynamic> json) {
    return DMHubOptions(
        trackUrl: json['trackUrl'],
        appId: json['appId'],
        appName: json['appName'])
      ..flushInterval = json['flushInterval']
      ..enableDebugLogging = json.boolValue('enableDebugLogging')
      ..autoTrackOpenAppEvent = json.boolValue('autoTrackOpenAppEvent')
      ..minimumActiveDuration = json.intValue('minimumActiveDuration', 10 * 1000)
      ..activeTimeoutDuration = json.intValue('activeTimeoutDuration', 9223372036854775807)
      ..maximumBackgroundDuration = json.intValue('maximumBackgroundDuration', 30 * 1000);
      
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['trackUrl'] = this.trackUrl;
    data['appId'] = this.appId;
    data['appName'] = this.appName;
    data['flushInterval'] = this.flushInterval;
    data['enableDebugLogging'] = this.enableDebugLogging;
    data['autoTrackOpenAppEvent'] = this.autoTrackOpenAppEvent;
    data['minimumActiveDuration'] = this.minimumActiveDuration;
    data['activeTimeoutDuration'] = this.activeTimeoutDuration;
    data['maximumBackgroundDuration'] = this.maximumBackgroundDuration;

    return data;
  }

  @override
  String toString() {
    return toJson().toString();
  }
}

==> dmhubsdk-1.0.7.tar.gz: lib/src/models/dmhub_options.dart <==
import 'dmhub_domain.dart';

class DMHubOptions {
  // collect options start
  // only collect for ios
  static const String COLLECT_IDFA = "idfa";

  // only collect for android
  static const String COLLECT_BLUETOOTH = "bluetooth";
  static const String COLLECT_MAC = "mac";
  static const String COLLECT_ANDROID_ID = "androidId";
  static const String COLLECT_IMEI = "imei";

  // collect for all
  static const String COLLECT_LOCATION = "location";
  static const String COLLECT_NETWORK_STATE = "networkState";
  static const String COLLECT_NETWORK_OPERATOR = "networkOperator";
  // collect options end



  /// convertlab appId,trackUrl,appName 必须设置。
  String? trackUrl;
  String? appId;
  String? appName;
  //flushInterval 上传数据的时间间隔（单位：秒），默认值：30
  int? flushInterval = 30; //only for ios
  bool? enableDebugLogging = true; //only for android
  bool? autoTrackOpenAppEvent = true; //only for all

  // 判断应用活跃时间上报需满足c  minimumActiveDuration <= 实际活跃时间 <= activeTimeoutDuration
  int minimumActiveDuration = 10 * 1000; // 进入后台时判定，距离上次最小活跃时间判定阈值
  int activeTimeoutDuration = 2147483647; // 进入后台是判定，最大活跃超时时间阈值，如果超出该阈值则断言为一个新的应用生命周期
  int maximumBackgroundDuration = 30 * 1000; // 从后台恢复时判定，最大后台活跃时间阈值，如果超出该阈值则判断位一个新的生命周期

  List<String>? disableCollect = <String>[];

  DMHubOptions(
      {required this.trackUrl,
      required this.appId,
      required this.appName,
      this.enableDebugLogging,
      this.autoTrackOpenAppEvent,
      this.disableCollect});

  factory DMHubOptions.fromJson(Map<String, dynamic> json) {
    return DMHubOptions(
        trackUrl: json['trackUrl'],
        appId: json['appId'],
        appName: json['appName'])
      ..flushInterval = json['flushInterval']
      ..enableDebugLogging = json.boolValue('enableDebugLogging')
      ..autoTrackOpenAppEvent = json.boolValue('autoTrackOpenAppEvent')
      ..minimumActiveDuration = json.intValue('minimumActiveDuration', 10 * 1000)
      ..activeTimeoutDuration = json.intValue('activeTimeoutDuration', 9223372036854775807)
      ..maximumBackgroundDuration = json.intValue('maximumBackgroundDuration', 30 * 1000)
      ..disableCollect = json.listStringValue('disableCollect');
      
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['trackUrl'] = this.trackUrl;
    data['appId'] = this.appId;
    data['appName'] = this.appName;
    data['flushInterval'] = this.flushInterval;
    data['enableDebugLogging'] = this.enableDebugLogging;
    data['autoTrackOpenAppEvent'] = this.autoTrackOpenAppEvent;
    data['minimumActiveDuration'] = this.minimumActiveDuration;
    data['activeTimeoutDuration'] = this.activeTimeoutDuration;
    data['maximumBackgroundDuration'] = this.maximumBackgroundDuration;
    data['disableCollect'] = this.disableCollect == null?<String>[]:this.disableCollect;

    return data;
  }

  @override
  String toString() {
    return toJson().toString();
  }
}
